dispMUA.arDispMUAAllocation["g"] =
{
  "gp software (www.dopus.com)" : [ "gp_opus.png" , "http://www.gpsoft.com.au/" ] ,
  "gp software directory opus" : [ "gp_opus.png" , "http://www.gpsoft.com.au/" ] ,
  "goto software sarbacane" : [ "sarbacane.png" , "http://www.goto-software.com/mailing/" ] ,
  "guweb mailing system" : [ "guweb_wonderbook.png" , "http://www.guweb.com/" ] ,
  "grono mailing system" : [ "grono.png" , "http://grono.net/" ] ,
  "gingin mail services" : [ "gingin.png" , "http://gaming.ngi.it/" ] ,
  "goabase email robot" : [ "goabase.png" , "http://www.goatrance.de/goabase/" ] ,
  "gordano messaging" : [ "gordano_ms.png" , "http://www.gordano.com/products/" ] ,
  "gimp useless mail" : [ "gimp.png" , "http://www.gimp.org/" ] ,
  "gaz via vbulletin" : [ "vbulletin.png" , "http://www.vbulletin.com/" ] ,
  "general wireless" : [ "mobispine.png" , "http://www.mobispine.com/" ] ,
  "geminisoft pimmy" : [ "pimmy.png" , "http://www.geminisoft.com/" ] ,
  "gigi's own news" : [ "gon.png" , "http://gon.sourceforge.net/" ] ,
  "groupware aipo" : [ "aipo.png" , "http://aipostyle.com/" ] ,
  "git-send-email" : [ "git.png" , "http://git-scm.com/" ] ,
  "gistron mailer" : [ "gistron_com.png" , "http://www.gistron.com/" ] ,
  "gigajob mailer" : [ "gigajob.png" , "http://www.gigajob.com/" ] ,
  "genesys e-mail" : [ "genesys7.png" , "http://www.genesyslab.com/" ] ,
  "gsd docuframe" : [ "docuframe.png" , "http://www.gsd-software.com/" ] ,
  "group-office" : [ "group_office.png" , "http://www.group-office.com/" ] ,
  "goodemail.cn" : [ "goodemail_cn.png" , "http://www.goodemail.cn/" ] ,
  "gs-shopmail" : [ "gs.png" , "https://www.gs-shopbuilder.de/" ] ,
  "groupwise 8" : [ "groupwise8.png" , "http://www.novell.com/products/groupwise/" ] ,
  "groundspeak" : [ "groundspeak.png" , "http://www.groundspeak.com/" ] ,
  "govdelivery" : [ "govdelivery.png" , "http://www.govdelivery.com/" ] ,
  "globalscape" : [ "globalscape.png" , "http://www.globalscape.com/" ] ,
  "getresponse" : [ "getresponse.png" , "http://www.getresponse.com/" ] ,
  "gsm-inform" : [ "gsm-inform.png" , "http://gsm-inform.ru/" ] ,
  "goowy mail" : [ "goowy_mail.png" , "http://www.goowy.com/" ] ,
  "gincko lab" : [ "gincko.png" , "http://gincko-lab.com/" ] ,
  "genie-soft" : [ "genie-soft.png" , "http://www.genie-soft.com/" ] ,
  "gandi mail" : [ "gandi_mail.png" , "http://www.gandi.net/domain/mail" ] ,
  "groupwise" : [ "groupwise.png" , "http://www.novell.com/products/groupwise/" ] ,
  "goodemail" : [ "goodemail_cn.png" , "http://www.goodemail.cn/" ] ,
  "globomail" : [ "globomail.png" , "http://webmail.globo.com/" ] ,
  "gedifmail" : [ "gedif.png" , "http://www.gedif.de/" ] ,
  "gatormail" : [ "gatormail.png" , "http://sourceforge.net/projects/gatormail/" ] ,
  "gyazmail" : [ "gyazmail.png" , "http://www.gyazsquare.com/gyazmail/" ] ,
  "goo mail" : [ "goo.png" , "http://mail.goo.ne.jp/" ] ,
  "goldmine" : [ "goldmine.png" , "http://www.goldmine.com/" ] ,
  "gnatsweb" : [ "gnatsweb.png" , "http://www.gnu.org/software/gnats/" ] ,
  "gbmailer" : [ "gbmailer.png" , "http://www.gboban.com/" ] ,
  "gatelist" : [ "gatelist.png" , "http://www.gatelist.com/" ] ,
  "gravity" : [ "microplanet.png" , "http://mpgravity.sourceforge.net/" ] ,
  "golded+" : [ "golded-plus.png" , "http://golded-plus.sourceforge.net/" ] ,
  "gnumail" : [ "gnumail.png" , "http://www.collaboration-world.com/gnumail" ] ,
  "gnspool" : [ "gnspool.png" , "http://www.freshports.org/japanese/gn-gnspool/" ] ,
  "gmx.com" : [ "gmx.png" , "http://www.gmx.com/" ] ,
  "genexus" : [ "genexus.png" , "http://www.genexus.com/" ] ,
  "gemini/" : [ "gemini.png" , "http://www.intellegit.com/software/gemini/" ] ,
  "geeklog" : [ "geeklog.png" , "http://www.geeklog.net/" ] ,
  "galette" : [ "galette.png" , "http://galette.tuxfamily.org/" ] ,
  "gnarwl" : [ "gnarwl.png" , "http://www.home.unix-ag.org/patrick/index.php?gnarwl" ] ,
  "gentoo" : [ "gentoo.png" , "http://www.gentoo.org/" ] ,
  "gemida" : [ "gemida_de.png" , "http://www.gemida.de/" ] ,
  "gcmail" : [ "gcmail.png" , "http://www.gcmail.de/" ] ,
  "gaucho" : [ "gaucho.png" , "http://www.bekkoame.ne.jp/~hiroshi-u/Gaucho/Gaucho.html" ] ,
  "gnus/" : [ "gnus.png" , "http://gnus.org/" ] ,
  "gnus " : [ "gnus.png" , "http://gnus.org/" ] ,
  "gs46" : [ "gs1ru.png" , "http://gs46.gs1ru.org/" ] ,
  "g2/" : [ "google_gmail.png" , "http://mail.google.com/" ] ,
}
